<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 21/03/19
 * Time: 14.49
 */

namespace FiloBlu\RuleDayFromBirthday\Model\Rule\Condition\Customer;

use Magento\Customer\Api\CustomerRepositoryInterface;
use Magento\Sales\Model\ResourceModel\Order\CollectionFactory;

class FirstOrder extends \Magento\Rule\Model\Condition\AbstractCondition
{

    /**
     * @var CustomerRepositoryInterface
     */
    protected $customerRepository;

    /**
     * @var \Magento\Sales\Model\ResourceModel\Order\CollectionFactory
     */
    protected $orderFactory;

    /**
     * Birthday constructor.
     * @param \Magento\Rule\Model\Condition\Context $context
     * @param CustomerRepositoryInterface $customerRepository
     * @param array $data
     */
    public function __construct(
        \Magento\Rule\Model\Condition\Context $context,
        CustomerRepositoryInterface $customerRepository,
        CollectionFactory $orderFactory,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->customerRepository = $customerRepository;
        $this->orderFactory = $orderFactory;
    }
    /**
     * Load attribute options
     *
     * @return $this
     */
    public function loadAttributeOptions()
    {
        $attributes = [
            'customer_first_order' => __("Days from customer's first order")
        ];
        $this->setAttributeOption($attributes);
        return $this;
    }
    /**
     * Get input type
     * Possible values are: string, numeric, date, select, multiselect, grid, boolean
     *
     * @return string
     */
    public function getInputType()
    {
        return 'string';
    }
    /**
     * Get value element type
     *
     * We have the value element types as select, text
     * @return string
     */
    public function getValueElementType()
    {
        return 'text';
    }


    /**
     * @param $dateString
     * @return \DateTime
     * @throws \Exception
     */
    protected function updateDate($dateString)
    {
        $suppliedDate = new \DateTime($dateString);
        $currentYear = (int)(new \DateTime())->format('Y');
        return (new \DateTime())->setDate($currentYear, (int)$suppliedDate->format('m'), (int)$suppliedDate->format('d'));
    }


    /**
     * Validate Customer Rule Condition
     *
     * @param \Magento\Framework\Model\AbstractModel $model
     * @return bool
     */
    protected function getDaysFromOrder($order_created_at)
    {
        $today = new \DateTime();
        $order_date = new \DateTime();
        $date_arr=explode('-',$order_created_at);
        $order_date->setDate((int)$date_arr[0],(int)$date_arr[1],(int)$date_arr[2]);
        $interval = $today->diff($order_date);
        return $interval->format('%a');
    }


    /**
     * @param \Magento\Framework\Model\AbstractModel $model
     * @return bool
     * @throws \Exception
     */
    public function validate(\Magento\Framework\Model\AbstractModel $model)
    {

        // Get the customer id of the current customer
        $customerId = (int)$model->getCustomerId();

        $order = $this->orderFactory->create($customerId);

        $all_orders = $order->getItems();
        $num_orders = count($all_orders);
        $order_created_at ='';

        if($num_orders == 1)
        {

            foreach ($all_orders as $items)
            {

              $order_created_at = $items->getCreatedAt();

            }

            $val = $this->getDaysFromOrder($order_created_at);
            $model->setData('customer_first_order', $val);

            return parent::validate($model);
        }
        else
        {
            return false;
        }



    }
}